@@ -27,6 +27,7 @@
 
 #include <gtk/gtkobject.h>
 #include <libgnomevfs/gnome-vfs-types.h>
+#include <libgnomevfs/gnome-vfs-volume.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 
 /* NautilusFile is an object used to represent a single element of a
@@ -73,6 +74,7 @@ typedef enum {
 #define NAUTILUS_FILE_EMBLEM_NAME_CANT_WRITE "nowrite"
 #define NAUTILUS_FILE_EMBLEM_NAME_TRASH "trash"
 #define NAUTILUS_FILE_EMBLEM_NAME_NOTE "note"
+#define NAUTILUS_FILE_EMBLEM_NAME_DESKTOP "desktop"
 
 typedef void (*NautilusFileCallback)          (NautilusFile  *file,
 				               gpointer       callback_data);
@@ -188,6 +190,12 @@ gboolean                nautilus_file_can_write                         (Nautilu
 gboolean                nautilus_file_can_execute                       (NautilusFile                   *file);
 gboolean                nautilus_file_can_rename                        (NautilusFile                   *file);
 
+/* Volumes. */
+gboolean                nautilus_file_has_volume                        (NautilusFile                   *file);
+gboolean                nautilus_file_has_drive                         (NautilusFile                   *file);
+GnomeVFSVolume *        nautilus_file_get_volume                        (NautilusFile                   *file);
+GnomeVFSDrive *         nautilus_file_get_drive                         (NautilusFile                   *file);
+
 /* Basic operations for file objects. */
 void                    nautilus_file_set_owner                         (NautilusFile                   *file,
 									 const char                     *user_name_or_id,
