@@ -28,6 +28,7 @@
 #define NAUTILUS_WINDOW_MANAGE_VIEWS_H
 
 #include "nautilus-window.h"
+#include "nautilus-navigation-window.h"
 
 void                    nautilus_window_manage_views_destroy         (NautilusWindow         *window);
 void                    nautilus_window_manage_views_finalize        (NautilusWindow         *window);
@@ -39,13 +40,21 @@ void                    nautilus_window_open_location_with_selection (NautilusWi
 void                    nautilus_window_stop_loading                 (NautilusWindow         *window);
 void                    nautilus_window_set_content_view             (NautilusWindow         *window,
                                                                       NautilusViewIdentifier *id);
-void                    nautilus_window_set_sidebar_panels           (NautilusWindow         *window,
-                                                                      GList                  *view_identifier_list);
-void                    nautilus_window_back_or_forward              (NautilusWindow         *window,
-                                                                      gboolean                back,
-                                                                      guint                   distance);
+
 gboolean                nautilus_window_content_view_matches_iid     (NautilusWindow         *window,
                                                                       const char             *iid);
 NautilusViewIdentifier *nautilus_window_get_content_view_id          (NautilusWindow         *window);
+void                    nautilus_window_connect_extra_view           (NautilusWindow         *window, 
+                                                                      NautilusViewFrame      *view,
+                                                                      NautilusViewIdentifier *id);
+void                    nautilus_window_disconnect_extra_view        (NautilusWindow         *window, 
+                                                                      NautilusViewFrame      *view);
+char                   *nautilus_window_get_view_frame_label         (NautilusViewFrame      *view);
+                                                                      
+void                    nautilus_navigation_window_set_sidebar_panels           (NautilusNavigationWindow         *window,
+                                                                                 GList                  *view_identifier_list);
+void                    nautilus_navigation_window_back_or_forward              (NautilusNavigationWindow         *window,
+                                                                                 gboolean                back,
+                                                                                 guint                   distance);
 
 #endif /* NAUTILUS_WINDOW_MANAGE_VIEWS_H */
