@@ -66,39 +66,40 @@ enum {
 
 static void
 activate_back_or_forward_menu_item (GtkMenuItem *menu_item, 
-				    NautilusWindow *window,
+				    NautilusNavigationWindow *window,
 				    gboolean back)
 {
 	int index;
 	
 	g_assert (GTK_IS_MENU_ITEM (menu_item));
-	g_assert (NAUTILUS_IS_WINDOW (window));
+	g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 
 	index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menu_item), "user_data"));
-	nautilus_window_back_or_forward (window, back, index);
+
+	nautilus_navigation_window_back_or_forward (window, back, index);
 }
 
 static void
-activate_back_menu_item_callback (GtkMenuItem *menu_item, NautilusWindow *window)
+activate_back_menu_item_callback (GtkMenuItem *menu_item, NautilusNavigationWindow *window)
 {
 	activate_back_or_forward_menu_item (menu_item, window, TRUE);
 }
 
 static void
-activate_forward_menu_item_callback (GtkMenuItem *menu_item, NautilusWindow *window)
+activate_forward_menu_item_callback (GtkMenuItem *menu_item, NautilusNavigationWindow *window)
 {
 	activate_back_or_forward_menu_item (menu_item, window, FALSE);
 }
 
 static GtkMenu *
-create_back_or_forward_menu (NautilusWindow *window, gboolean back)
+create_back_or_forward_menu (NautilusNavigationWindow *window, gboolean back)
 {
 	GtkMenu *menu;
 	GtkWidget *menu_item;
 	GList *list_link;
 	int index;
 
-	g_assert (NAUTILUS_IS_WINDOW (window));
+	g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 	
 	menu = GTK_MENU (gtk_menu_new ());
 
@@ -124,17 +125,15 @@ create_back_or_forward_menu (NautilusWindow *window, gboolean back)
 }
 
 static GtkWidget *
-get_back_button (NautilusWindow *window)
+get_back_button (NautilusNavigationWindow *window)
 {
-	return GTK_WIDGET (GTK_BIN 
-		(window->details->back_button_item)->child);
+	return window->details->back_button_item;
 }
 
 static GtkWidget *
-get_forward_button (NautilusWindow *window)
+get_forward_button (NautilusNavigationWindow *window)
 {
-	return GTK_WIDGET (GTK_BIN
-		(window->details->forward_button_item)->child);
+	return window->details->forward_button_item;
 }
 
 static void
@@ -142,15 +141,14 @@ menu_position_under_widget (GtkMenu *menu, int *x, int *y,
 			    gboolean *push_in, gpointer user_data)
 {
 	GtkWidget *w;
-	int width, height;
 	int screen_width, screen_height;
 	GtkRequisition requisition;
 
 	w = GTK_WIDGET (user_data);
 	
-	gdk_drawable_get_size (w->window, &width, &height);
 	gdk_window_get_origin (w->window, x, y);
-	*y = *y + height;
+	*x += w->allocation.x;
+	*y += w->allocation.y + w->allocation.height;
 
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
@@ -166,20 +164,20 @@ back_or_forward_button_pressed_callback (GtkWidget *widget,
 					 GdkEventButton *event,
 					 gpointer *user_data)
 {
-	NautilusWindow *window;
+	NautilusNavigationWindow *window;
 	gboolean back;
 
 	g_return_val_if_fail (GTK_IS_BUTTON (widget), FALSE);
-	g_return_val_if_fail (NAUTILUS_IS_WINDOW (user_data), FALSE);
+	g_return_val_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (user_data), FALSE);
 
-	window = NAUTILUS_WINDOW (user_data);
+	window = NAUTILUS_NAVIGATION_WINDOW (user_data);
 
 	back = widget == get_back_button (window);
 	g_assert (back || widget == get_forward_button (window));
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
-	gnome_popup_menu_do_popup_modal (GTK_WIDGET (create_back_or_forward_menu (NAUTILUS_WINDOW (user_data), back)),
+	gnome_popup_menu_do_popup_modal (GTK_WIDGET (create_back_or_forward_menu (NAUTILUS_NAVIGATION_WINDOW (user_data), back)),
 					 menu_position_under_widget, widget, event, widget, widget);
 	
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
@@ -202,62 +200,26 @@ back_or_forward_key_pressed_callback (GtkWidget *widget,
 	return FALSE;
 }
 
-static void
-back_or_forward_toolbar_item_property_set_cb (BonoboPropertyBag *bag,
-					      const BonoboArg   *arg,
-					      guint              arg_id,
-					      CORBA_Environment *ev,
-					      gpointer           user_data)
-{
-	BonoboControl *control;
-	BonoboUIToolbarItem *item;
-	GtkOrientation orientation;
-	BonoboUIToolbarItemStyle style;
-
-	control = BONOBO_CONTROL (user_data);
-	item = BONOBO_UI_TOOLBAR_ITEM (bonobo_control_get_widget (control));
-
-	switch (arg_id) {
-	case TOOLBAR_ITEM_ORIENTATION_PROP:
-		orientation = BONOBO_ARG_GET_INT (arg);
-		bonobo_ui_toolbar_item_set_orientation (item, orientation);
-
-		if (GTK_WIDGET (item)->parent) {
-			gtk_widget_queue_resize (GTK_WIDGET (item)->parent);
-		}
-		break;
-	case TOOLBAR_ITEM_STYLE_PROP:
-		style = BONOBO_ARG_GET_INT (arg);
-		bonobo_ui_toolbar_item_set_style (item, style);
-		break;
-	}
-}
-
-static BonoboUIToolbarItem *
-create_back_or_forward_toolbar_item (NautilusWindow *window, 
+static GtkWidget *
+create_back_or_forward_toolbar_item (NautilusNavigationWindow *window, 
 				     const char     *tooltip,
 				     const char     *control_path)
 {
-	BonoboUIToolbarItem *item;
-	BonoboPropertyBag *pb;
-	BonoboControl *wrapper;
 	GtkWidget *button;
 
-	item = BONOBO_UI_TOOLBAR_ITEM (bonobo_ui_toolbar_item_new ());
-
 	button = gtk_toggle_button_new ();
+
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
 
 	gtk_container_add (GTK_CONTAINER (button),
 			   gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT));
 
-	gtk_container_add (GTK_CONTAINER (item), button);
-
-	gtk_widget_show_all (GTK_WIDGET (item));
+	gtk_widget_show_all (GTK_WIDGET (button));
 
 	gtk_tooltips_set_tip (window->details->tooltips,
 			      GTK_WIDGET (button),
 			      tooltip, NULL);
+
 	g_signal_connect_object (button, "key_press_event",
 				 G_CALLBACK (back_or_forward_key_pressed_callback),
 				 window, 0);
@@ -265,32 +227,16 @@ create_back_or_forward_toolbar_item (NautilusWindow *window,
 				 G_CALLBACK (back_or_forward_button_pressed_callback),
 				 window, 0);
 
-	wrapper = bonobo_control_new (GTK_WIDGET (item));
-	pb = bonobo_property_bag_new
-		(NULL, back_or_forward_toolbar_item_property_set_cb, wrapper);
-	bonobo_property_bag_add (pb, "style",
-				 TOOLBAR_ITEM_STYLE_PROP,
-				 BONOBO_ARG_INT, NULL, NULL,
-				 Bonobo_PROPERTY_WRITEABLE);
-	bonobo_property_bag_add (pb, "orientation",
-				 TOOLBAR_ITEM_ORIENTATION_PROP,
-				 BONOBO_ARG_INT, NULL, NULL,
-				 Bonobo_PROPERTY_WRITEABLE);
-	bonobo_control_set_properties (wrapper, BONOBO_OBJREF (pb), NULL);
-	bonobo_object_unref (pb);
-
-	bonobo_ui_component_object_set (window->details->shell_ui,
+	bonobo_ui_component_widget_set (NAUTILUS_WINDOW (window)->details->shell_ui,
 					control_path,
-					BONOBO_OBJREF (wrapper),
+					button,
 					NULL);
 
-	bonobo_object_unref (wrapper);
-
-	return item;
+	return button;
 }
 
 static void
-throbber_set_throbbing (NautilusWindow *window,
+throbber_set_throbbing (NautilusNavigationWindow *window,
 			gboolean        throbbing)
 {
 	CORBA_boolean b;
@@ -311,7 +257,7 @@ throbber_created_callback (Bonobo_Unknown     throbber,
 			   gpointer           user_data)
 {
 	char *exception_as_text;
-	NautilusWindow *window;
+	NautilusNavigationWindow *window;
 
 	if (BONOBO_EX (ev)) {
 		exception_as_text = bonobo_exception_get_text (ev);
@@ -320,13 +266,13 @@ throbber_created_callback (Bonobo_Unknown     throbber,
 		return;
 	}
 
-	g_return_if_fail (NAUTILUS_IS_WINDOW (user_data));
+	g_return_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (user_data));
 
-	window = NAUTILUS_WINDOW (user_data);
+	window = NAUTILUS_NAVIGATION_WINDOW (user_data);
 
 	window->details->throbber_activating = FALSE;
 
-	bonobo_ui_component_object_set (window->details->shell_ui,
+	bonobo_ui_component_object_set (NAUTILUS_WINDOW (window)->details->shell_ui,
 					"/Toolbar/ThrobberWrapper",
 					throbber, ev);
 	CORBA_exception_free (ev);
@@ -347,7 +293,8 @@ throbber_created_callback (Bonobo_Unknown     throbber,
 }
 
 void
-nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
+nautilus_navigation_window_set_throbber_active (NautilusNavigationWindow *window, 
+						gboolean allow)
 {
 	if (( window->details->throbber_active &&  allow) ||
 	    (!window->details->throbber_active && !allow)) {
@@ -359,23 +306,17 @@ nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 	else
 		access ("nautilus-throbber: stop", 0);
 
-	window->details->throbber_active = allow;
-
-	nautilus_window_ui_freeze (window);
-
-	nautilus_bonobo_set_sensitive (window->details->shell_ui,
+	nautilus_bonobo_set_sensitive (NAUTILUS_WINDOW (window)->details->shell_ui,
 				       NAUTILUS_COMMAND_STOP, allow);
 
+	window->details->throbber_active = allow;
 	if (window->details->throbber_property_bag != CORBA_OBJECT_NIL) {
 		throbber_set_throbbing (window, allow);
 	}
-
-	nautilus_window_ui_thaw (window);
 }
 
-
 void
-nautilus_window_activate_throbber (NautilusWindow *window)
+nautilus_navigation_window_activate_throbber (NautilusNavigationWindow *window)
 {
 	CORBA_Environment ev;
 	char *exception_as_text;
@@ -410,13 +351,11 @@ nautilus_window_activate_throbber (NautilusWindow *window)
 }
 
 void
-nautilus_window_initialize_toolbars (NautilusWindow *window)
+nautilus_navigation_window_initialize_toolbars (NautilusNavigationWindow *window)
 {
-	nautilus_window_ui_freeze (window);
+	nautilus_window_ui_freeze (NAUTILUS_WINDOW (window));
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR)) {
-		nautilus_window_activate_throbber (window);
-	}
+	nautilus_navigation_window_activate_throbber (window);
 
 	window->details->back_button_item = create_back_or_forward_toolbar_item 
 		(window, _("Go back a few pages"),
@@ -425,5 +364,5 @@ nautilus_window_initialize_toolbars (NautilusWindow *window)
 		(window, _("Go forward a number of pages"),
 		 "/Toolbar/ForwardMenu");
 
-	nautilus_window_ui_thaw (window);
+	nautilus_window_ui_thaw (NAUTILUS_WINDOW (window));
 }
